CONTRIBUTORS
============

This is a list of people who have made contributions.

Feel free to add your name if missing

People are listed alphabetically,

- Anne Biton
- Bryan Brancotte <https://github.com/bryan-brancotte/>
- Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
- Sulyvan Dollin
- Yoann Dufresne <https://github.com/yoann-dufresne>
- Kenzo-Hugo Hillion <kehillio@pasteur.fr>
- Pierre LECHAT  <plechat@pasteur.fr>
- Rachel Legendre
- Blaise Li <https://github.com/blaiseli>
- Bertrand Néron <https://github.com/bneron>
- Etienne Kornobis <https://github.com/khourhin>
- Frederic Lemoine
- Nicolas MAILLET
- Amandine Perrin
- Nicolas Traut
- Anna Zhukova
